# -*- coding: utf-8 -*-

"""
Mobcrush API Wrapper
~~~~~~~~~~~~~~~~~~~
A basic wrapper for the Mobcrush API.
:copyright: (c) 2017 Jay Nagpaul
:license: MIT, see LICENSE for more details.
"""

from .main import *
from . import datatypes
